==> Games-TicTacToe-0.22.tar.gz: Games-TicTacToe-0.22/lib/Games/TicTacToe/Params.pm <==
package Games::TicTacToe::Params;

$Games::TicTacToe::Params::VERSION = '0.22';
$Games::TicTacToe::Params::AUTHOR  = 'cpan:MANWAR';

=head1 NAME

Games::TicTacToe::Params - Placeholder for parameters for Games::TicTacToe.

=head1 VERSION

Version 0.22

=cut

use 5.006;
use strict; use warnings;
use Data::Dumper;

use Type::Library -base, -declare => qw(Board Player Players PlayerObj Symbol Type);
use Types::Standard qw(Str Object ArrayRef);
use Type::Utils;

declare 'Board',
    as Object,
    where   { defined $_[0] || $_[0]->isa('Games::TicTacToe::Board') },
    message { "isa check for 'board' failed." };

declare 'Player',
    as Str,
    where   { (defined $_[0] && $_[0] =~ /^[H|C]$/i) },
    message { "isa check for 'player' failed." };

declare 'PlayerObj',
    as Object,
    where   { ref($_[0]) eq 'Games::TicTacToe::Player' };

declare 'Players',
    as ArrayRef[PlayerObj],
    message { "isa check for 'players' failed." };

declare 'Symbol',
    as Str,
    where   { (defined $_[0] && $_[0] =~ /^[X|O]$/i) },
    message { "isa check for 'symbol' failed." };

declare 'Type',
    as Str,
    where   { (defined $_[0] && $_[0] =~ /^[H|C]$/i) },
    message { "isa check for 'type' failed." };

=head1 DESCRIPTION

It is used internally by L<Games::TicTacToe>.

=head1 AUTHOR

Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>

=head1 REPOSITORY

L<https://github.com/manwar/Games-TicTacToe>

=head1 BUGS

Please report any bugs / feature requests to C<bug-games-tictactoe at rt.cpan.org>
or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-TicTacToe>.
I will be notified & then you'll automatically be notified of progress on your bug
as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Games::TicTacToe::Params

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-TicTacToe>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Games-TicTacToe>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Games-TicTacToe>

=item * Search CPAN

L<http://search.cpan.org/dist/Games-TicTacToe/>

=back

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2011 - 2016 Mohammad S Anwar.

This  program  is  free software;  you can redistribute it and/or modify it under
the  terms  of the the Artistic  License (2.0). You may obtain a copy of the full
license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any  use,  modification, and distribution of the Standard or Modified Versions is
governed by this Artistic License.By using, modifying or distributing the Package,
you accept this license. Do not use, modify, or distribute the Package, if you do
not accept this license.

If your Modified Version has been derived from a Modified Version made by someone
other than you,you are nevertheless required to ensure that your Modified Version
 complies with the requirements of this license.

This  license  does  not grant you the right to use any trademark,  service mark,
tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge patent license
to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
Package with respect to any patent claims licensable by the Copyright Holder that
are  necessarily  infringed  by  the  Package. If you institute patent litigation
(including  a  cross-claim  or  counterclaim) against any party alleging that the
Package constitutes direct or contributory patent infringement,then this Artistic
License to you shall terminate on the date that such litigation is filed.

Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut

1; # End of Games::TicTacToe::Params

==> Games-TicTacToe-0.24.tar.gz: Games-TicTacToe-0.24/lib/Games/TicTacToe/Params.pm <==
package Games::TicTacToe::Params;

$Games::TicTacToe::Params::VERSION = '0.24';
$Games::TicTacToe::Params::AUTHOR  = 'cpan:MANWAR';

=head1 NAME

Games::TicTacToe::Params - Placeholder for parameters for Games::TicTacToe.

=head1 VERSION

Version 0.24

=cut

use 5.006;
use strict; use warnings;
use Data::Dumper;

use Type::Library -base, -declare => qw(Board Player Players PlayerType Symbol Type);
use Types::Standard qw(Str ArrayRef);
use Type::Utils;

class_type 'Board' , { class => 'Games::TicTacToe::Board'  };
class_type 'Player', { class => 'Games::TicTacToe::Player' };

declare 'PlayerType',
    as Str,
    where   { (defined $_[0] && $_[0] =~ /^[H|C]$/i) },
    message { "isa check for 'PlayerType' failed." };

declare 'Players',
    as ArrayRef[Player],
    message { "isa check for 'players' failed." };

declare 'Symbol',
    as Str,
    where   { (defined $_[0] && $_[0] =~ /^[X|O]$/i) },
    message { "isa check for 'symbol' failed." };

declare 'Type',
    as Str,
    where   { (defined $_[0] && $_[0] =~ /^[H|C]$/i) },
    message { "isa check for 'type' failed." };

=head1 DESCRIPTION

It is used internally by L<Games::TicTacToe>.

=head1 AUTHOR

Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>

=head1 REPOSITORY

L<https://github.com/manwar/Games-TicTacToe>

=head1 BUGS

Please report any bugs / feature requests to C<bug-games-tictactoe at rt.cpan.org>
or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-TicTacToe>.
I will be notified & then you'll automatically be notified of progress on your bug
as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Games::TicTacToe::Params

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-TicTacToe>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Games-TicTacToe>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Games-TicTacToe>

=item * Search CPAN

L<http://search.cpan.org/dist/Games-TicTacToe/>

=back

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2011 - 2016 Mohammad S Anwar.

This  program  is  free software;  you can redistribute it and/or modify it under
the  terms  of the the Artistic  License (2.0). You may obtain a copy of the full
license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any  use,  modification, and distribution of the Standard or Modified Versions is
governed by this Artistic License.By using, modifying or distributing the Package,
you accept this license. Do not use, modify, or distribute the Package, if you do
not accept this license.

If your Modified Version has been derived from a Modified Version made by someone
other than you,you are nevertheless required to ensure that your Modified Version
 complies with the requirements of this license.

This  license  does  not grant you the right to use any trademark,  service mark,
tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge patent license
to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
Package with respect to any patent claims licensable by the Copyright Holder that
are  necessarily  infringed  by  the  Package. If you institute patent litigation
(including  a  cross-claim  or  counterclaim) against any party alleging that the
Package constitutes direct or contributory patent infringement,then this Artistic
License to you shall terminate on the date that such litigation is filed.

Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut

1; # End of Games::TicTacToe::Params
